Description Usage Arguments Value Examples
degree calculates the standardized degree centrality of the network;
a higher degree centrality indicates the node has more connections to
other nodes
1 |
A.mat |
An n x n adjacency matrix. |
type |
A character string indicating the type of degree centrality: "undirected", "indegree", or "outdegree". By default, it is "undirected". |
Returns the value of c.degree.std, a length-n vector
of degree centrality scores
1 2 3 | A.mat = sim_adjacency(10, mode = "directed") # generate digraph
degree(A.mat) # consider both in and out degrees
degree(A.mat, type = "indegree") # only count indegree
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.